dag_cbor.random
===============

.. automodule:: dag_cbor.random

default_options
---------------

.. autofunction:: dag_cbor.random.default_options

get_options
-----------

.. autofunction:: dag_cbor.random.get_options

options
-------

.. autofunction:: dag_cbor.random.options

rand_bool
---------

.. autofunction:: dag_cbor.random.rand_bool

rand_bool_none
--------------

.. autofunction:: dag_cbor.random.rand_bool_none

rand_bytes
----------

.. autofunction:: dag_cbor.random.rand_bytes

rand_cid
--------

.. autofunction:: dag_cbor.random.rand_cid

rand_data
---------

.. autofunction:: dag_cbor.random.rand_data

rand_data_cid
-------------

.. autofunction:: dag_cbor.random.rand_data_cid

rand_dict
---------

.. autofunction:: dag_cbor.random.rand_dict

rand_float
----------

.. autofunction:: dag_cbor.random.rand_float

rand_int
--------

.. autofunction:: dag_cbor.random.rand_int

rand_list
---------

.. autofunction:: dag_cbor.random.rand_list

rand_str
--------

.. autofunction:: dag_cbor.random.rand_str

reset_options
-------------

.. autofunction:: dag_cbor.random.reset_options

set_options
-----------

.. autofunction:: dag_cbor.random.set_options
